@@ -32,7 +32,8 @@ from vermouth.citation_parser import citation_formatter
 from vermouth.graph_utils import make_residue_graph
 from polyply import (MetaMolecule, ApplyLinks, Monomer, MapToMolecule)
 from polyply.src.graph_utils import find_missing_edges
-from .load_library import load_library
+from .load_library import load_ff_library
+from .gen_dna import complement_dsDNA
 
 LOGGER = StyleAdapter(get_logger(__name__))
 
@@ -59,7 +60,7 @@ def split_seq_string(sequence):
         monomers.append(Monomer(resname=resname, n_blocks=n_blocks))
     return monomers
 
-def gen_params(name="polymer", outpath=Path("polymer.itp"), inpath=None, lib=None, seq=None, seq_file=None):
+def gen_params(name="polymer", outpath=Path("polymer.itp"), inpath=[], lib=None, seq=None, seq_file=None, dsdna=False):
     """
     Top level function for running the polyply parameter generation.
     Parameters seq and seq_file are mutually exclusive. Set the other
@@ -83,7 +84,7 @@ def gen_params(name="polymer", outpath=Path("polymer.itp"), inpath=None, lib=Non
     """
     # Import of Itp and FF files
     LOGGER.info("reading input and library files",  type="step")
-    force_field = load_library(name, lib, inpath)
+    force_field = load_ff_library(name, lib, inpath)
 
     # Generate the MetaMolecule
     if seq:
@@ -96,6 +97,10 @@ def gen_params(name="polymer", outpath=Path("polymer.itp"), inpath=None, lib=Non
         LOGGER.info("reading sequence from file",  type="step")
         meta_molecule = MetaMolecule.from_sequence_file(force_field, seq_file, name)
 
+    # Generate complementary DNA strand
+    if dsdna:
+        complement_dsDNA(meta_molecule)
+
     # Do transformationa and apply link
     LOGGER.info("mapping sequence to molecule",  type="step")
     meta_molecule = MapToMolecule(force_field).run_molecule(meta_molecule)
@@ -103,12 +108,9 @@ def gen_params(name="polymer", outpath=Path("polymer.itp"), inpath=None, lib=Non
     meta_molecule = ApplyLinks().run_molecule(meta_molecule)
 
     # Raise warning if molecule is disconnected
-    if not nx.is_connected(meta_molecule.molecule):
-        LOGGER.warning("Your molecule consists of disjoint parts."
-                       "Perhaps links were not applied correctly.")
-        msg = "Missing link between residue {idxA} {resA} and residue {idxB} {resB}"
-        for missing in find_missing_edges(meta_molecule, meta_molecule.molecule):
-            LOGGER.warning(msg, **missing)
+    msg = "Missing a link between residue {idxA} {resA} and residue {idxB} {resB}."
+    for missing in find_missing_edges(meta_molecule, meta_molecule.molecule):
+        LOGGER.warning(msg, **missing)
 
     with deferred_open(outpath, 'w') as outfile:
         header = [ ' '.join(sys.argv) + "\n" ]
