@@ -166,7 +166,7 @@ def optimize_geometry(block, coords, inter_types=[], tolerance={"angles": 5,
     """
     n_atoms = len(coords)
     atom_to_idx = OrderedDict(zip(list(coords.keys()), range(0, n_atoms)))
-    positions = np.array(list(coords.values()))
+    positions = np.ravel(np.array(list(coords.values())))
 
     def target_function(positions):
         energy = 0
